@@ -25,12 +25,13 @@ public slots:
     bool xTubeInstalled();
     void setMediaPlayer(const QString &player);
     void getMediaPlayerFromDB();
+    QStringList getProxyFromDB() const;
     void toggleState();
     void minimize();
     void playVideo(const QString &url);
     void deleteVideo(const QString &path);
     void convertToAudio(const QString &input);
-    QString archiveFileExists(const QString &filePath, const QString &archivePath);
+    QString archiveFileExists(const QString &filePath, const QString &archivePath) const;
     bool pathExists(const QString &path);
     void copyToClipboard(const QString &url);
 
