@@ -5,8 +5,8 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.6.3</source>
-        <translation></translation>
+        <source>cuteTube-QML - 0.6.5</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -38,12 +38,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="107"/>
+        <location filename="../AccountDetailsDialog.qml" line="95"/>
         <source>Password</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="132"/>
+        <location filename="../AccountDetailsDialog.qml" line="108"/>
         <source>Default?</source>
         <translation></translation>
     </message>
@@ -74,12 +74,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="87"/>
+        <location filename="../AddCommentDialog.qml" line="74"/>
         <source>Description</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="124"/>
+        <location filename="../AddCommentDialog.qml" line="111"/>
         <source>Message</source>
         <translation></translation>
     </message>
@@ -167,99 +167,26 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
-        <source>English</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="47"/>
-        <source>German</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="48"/>
-        <source>Italian</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="49"/>
-        <source>Finnish</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="50"/>
-        <source>Dutch</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="51"/>
-        <source>Polish</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="177"/>
+        <location filename="../../../controller.cpp" line="181"/>
         <source>Video deleted from device</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="180"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Unable to delete video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="184"/>
+        <location filename="../../../controller.cpp" line="188"/>
         <source>Video not found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="239"/>
+        <location filename="../../../controller.cpp" line="243"/>
         <source>Copied to clipboard</source>
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>DownloadListDelegate</name>
-    <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
-        <source>Paused</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
-        <source>Queued</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
-        <source>Failed</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../DownloadListDelegate.qml" line="66"/>
-        <source>Downloading</source>
-        <translation></translation>
-    </message>
-</context>
-<context>
-    <name>DownloadManager</name>
-    <message>
-        <location filename="../../../downloadmanager.cpp" line="37"/>
-        <location filename="../../../downloadmanager.cpp" line="66"/>
-        <location filename="../../../downloadmanager.cpp" line="159"/>
-        <source>Failed</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../downloadmanager.cpp" line="121"/>
-        <source>Downloading</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../downloadmanager.cpp" line="156"/>
-        <source>Paused</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>FileChooserDialog</name>
     <message>
@@ -380,12 +307,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="71"/>
+        <location filename="../NewPlaylistDialog.qml" line="59"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="95"/>
+        <location filename="../NewPlaylistDialog.qml" line="71"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -508,33 +435,48 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>ProxyDialog</name>
+    <message>
+        <location filename="../ProxyDialog.qml" line="30"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="44"/>
+        <source>Host (e.g. 192.168.100.1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="51"/>
+        <source>Port (e.g. 8080)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchBar</name>
     <message>
-        <location filename="../SearchBar.qml" line="116"/>
-        <location filename="../SearchBar.qml" line="126"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Date</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="117"/>
-        <location filename="../SearchBar.qml" line="119"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Relevance</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="120"/>
-        <location filename="../SearchBar.qml" line="122"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Rating</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="123"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Views</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="176"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation></translation>
     </message>
@@ -542,223 +484,305 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="189"/>
         <source>Your saved searches have been cleared</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="192"/>
         <source>Database error. Unable to clear searches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="196"/>
+        <location filename="../SettingsDialog.qml" line="239"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="229"/>
+        <location filename="../SettingsDialog.qml" line="280"/>
         <source>Playback quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="237"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Download quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="245"/>
+        <location filename="../SettingsDialog.qml" line="296"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="253"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Download location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="269"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Screen orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="135"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
-        <location filename="../SettingsDialog.qml" line="466"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="345"/>
+        <location filename="../SettingsDialog.qml" line="537"/>
         <source>Language</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="111"/>
-        <location filename="../SettingsDialog.qml" line="320"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="43"/>
+        <source>Russian</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most viewed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Archive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Latest subscription videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My uploads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="117"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="141"/>
+        <location filename="../SettingsDialog.qml" line="391"/>
         <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
-        <location filename="../SettingsDialog.qml" line="338"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="409"/>
         <source>Download Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="117"/>
-        <location filename="../SettingsDialog.qml" line="356"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="427"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="126"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
+        <location filename="../SettingsDialog.qml" line="483"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="129"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="501"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
         <source>Mobile</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <source>High Quality</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
         <location filename="../SettingsDialog.qml" line="39"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="42"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="46"/>
-        <location filename="../SettingsDialog.qml" line="78"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="49"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Automatic</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Landscape</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Portrait</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Light</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Dark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>English</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>German</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Finnish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Italian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Dutch</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Polish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="73"/>
-        <source>Queued</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
-        <source>Paused</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="85"/>
+        <location filename="../SettingsDialog.qml" line="102"/>
         <source>Your settings have been saved</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="90"/>
-        <location filename="../SettingsDialog.qml" line="120"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
         <source>Download Path</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="92"/>
+        <location filename="../SettingsDialog.qml" line="109"/>
         <source>Download Location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="123"/>
-        <location filename="../SettingsDialog.qml" line="261"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="465"/>
         <source>Safe Search</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="132"/>
-        <location filename="../SettingsDialog.qml" line="285"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
+        <location filename="../SettingsDialog.qml" line="519"/>
         <source>Theme</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="480"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="619"/>
+        <source>Widget Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="174"/>
+        <location filename="../SettingsDialog.qml" line="639"/>
+        <source>Widget Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="659"/>
+        <source>Widget Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="679"/>
+        <source>Widget Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="272"/>
+        <source>Network proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="312"/>
+        <source>Safe search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="364"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="568"/>
+        <source>Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="576"/>
+        <source>Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="584"/>
+        <source>Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="592"/>
+        <source>Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="694"/>
         <source>Clear saved searches</source>
         <translation></translation>
     </message>
@@ -870,7 +894,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="251"/>
+        <location filename="../UploadDialog.qml" line="215"/>
         <source>Category</source>
         <translation></translation>
     </message>
@@ -886,7 +910,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="259"/>
+        <location filename="../UploadDialog.qml" line="223"/>
         <source>None chosen</source>
         <translation></translation>
     </message>
@@ -896,17 +920,17 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="176"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="212"/>
+        <location filename="../UploadDialog.qml" line="188"/>
         <source>Tags (seperated by commas)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="237"/>
+        <location filename="../UploadDialog.qml" line="201"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -1197,14 +1221,6 @@
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>VideoPlaybackView</name>
-    <message>
-        <location filename="../VideoPlaybackView.qml" line="60"/>
-        <source>Error: Unable to retrieve video</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>Widget</name>
     <message>
@@ -1216,68 +1232,56 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="39"/>
+        <location filename="../../../youtube.cpp" line="40"/>
         <source>Error obtaining access token</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="49"/>
+        <location filename="../../../youtube.cpp" line="50"/>
         <source>Authentication failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="52"/>
+        <location filename="../../../youtube.cpp" line="53"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="116"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Error - Server repsonse is: </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="166"/>
+        <location filename="../../../youtube.cpp" line="174"/>
         <source>Upload aborted</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="181"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="191"/>
         <source>Upload is completed</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="382"/>
+        <location filename="../../../youtube.cpp" line="419"/>
         <source>Error: Unable to retrieve video</source>
         <translation></translation>
     </message>
 </context>
 <context>
     <name>main</name>
-    <message>
-        <location filename="../main.qml" line="18"/>
-        <source>Dark</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="21"/>
-        <location filename="../main.qml" line="22"/>
-        <location filename="../main.qml" line="23"/>
-        <location filename="../main.qml" line="24"/>
-        <source>Light</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../main.qml" line="109"/>
         <source>Video(s) added to download queue</source>
@@ -1304,9 +1308,9 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="200"/>
-        <source>Converting</source>
-        <translation></translation>
+        <location filename="../main.qml" line="204"/>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../main.qml" line="209"/>
@@ -1319,24 +1323,57 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="230"/>
-        <location filename="../main.qml" line="270"/>
+        <location filename="../main.qml" line="224"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>Mobile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>360p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>480p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>720p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
         <source>Queued</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
+        <location filename="../main.qml" line="225"/>
         <source>Paused</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="225"/>
+        <source>Downloading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
+        <source>Failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="422"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="423"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1349,93 +1386,34 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="133"/>
+        <location filename="../scripts/mainscripts.js" line="134"/>
         <source>Archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="172"/>
+        <location filename="../scripts/mainscripts.js" line="173"/>
         <source>My Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="182"/>
+        <location filename="../scripts/mainscripts.js" line="183"/>
         <source>My Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="195"/>
+        <location filename="../scripts/mainscripts.js" line="196"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="204"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>Video Playback</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="214"/>
-        <source>Downloads</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="222"/>
-        <source>date</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="225"/>
-        <source>views</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="228"/>
-        <source>relevance</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="231"/>
-        <source>rating</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="239"/>
+        <location filename="../scripts/mainscripts.js" line="218"/>
         <source>Search </source>
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>settings</name>
-    <message>
-        <location filename="../scripts/settings.js" line="126"/>
-        <location filename="../scripts/settings.js" line="127"/>
-        <source>High Quality</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/settings.js" line="128"/>
-        <source>Paused</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/settings.js" line="131"/>
-        <source>Automatic</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/settings.js" line="133"/>
-        <source>Date</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/settings.js" line="134"/>
-        <source>Dark</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/settings.js" line="135"/>
-        <source>English</source>
-        <translation></translation>
-    </message>
-</context>
 </TS>
