@@ -12,9 +12,13 @@
         <translation type="obsolete">cuteTube-QML - 0.6.1 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.6.3</source>
-        <translation>cuteTube-QML - 0.6.3 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.6.3 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.5</source>
+        <translation type="unfinished">cuteTube-QML - 0.6.5 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -46,12 +50,12 @@
         <translation>Käyttäjätunnus</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="107"/>
+        <location filename="../AccountDetailsDialog.qml" line="95"/>
         <source>Password</source>
         <translation>Salasana</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="132"/>
+        <location filename="../AccountDetailsDialog.qml" line="108"/>
         <source>Default?</source>
         <translation>Oletus?</translation>
     </message>
@@ -82,12 +86,12 @@
         <translation>Otsikko</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="87"/>
+        <location filename="../AddCommentDialog.qml" line="74"/>
         <source>Description</source>
         <translation>Kuvaus</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="124"/>
+        <location filename="../AddCommentDialog.qml" line="111"/>
         <source>Message</source>
         <translation>Viesti</translation>
     </message>
@@ -175,52 +179,42 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
-        <translation>Englanti</translation>
+        <translation type="obsolete">Englanti</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
-        <translation>Saksa</translation>
+        <translation type="obsolete">Saksa</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
-        <source>Italian</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
-        <translation>Suomi</translation>
+        <translation type="obsolete">Suomi</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="50"/>
         <source>Dutch</source>
-        <translation>Alankomaiden</translation>
+        <translation type="obsolete">Alankomaiden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="51"/>
         <source>Polish</source>
-        <translation>Puolalainen</translation>
+        <translation type="obsolete">Puolalainen</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="177"/>
+        <location filename="../../../controller.cpp" line="181"/>
         <source>Video deleted from device</source>
         <translation>Video poistettu laitteesta</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="180"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Unable to delete video</source>
         <translation>Videon poisto epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="184"/>
+        <location filename="../../../controller.cpp" line="188"/>
         <source>Video not found</source>
         <translation>Videota ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="239"/>
+        <location filename="../../../controller.cpp" line="243"/>
         <source>Copied to clipboard</source>
         <translation>Kopioitu leikepöydälle</translation>
     </message>
@@ -228,44 +222,35 @@
 <context>
     <name>DownloadListDelegate</name>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Paused</source>
-        <translation>Pysäytetty</translation>
+        <translation type="obsolete">Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Queued</source>
-        <translation>Jonossa</translation>
+        <translation type="obsolete">Jonossa</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Failed</source>
-        <translation>Epäonnistunut</translation>
+        <translation type="obsolete">Epäonnistunut</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="66"/>
         <source>Downloading</source>
-        <translation>Ladataan</translation>
+        <translation type="obsolete">Ladataan</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="37"/>
-        <location filename="../../../downloadmanager.cpp" line="66"/>
-        <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
-        <translation>Epäonnistui</translation>
+        <translation type="obsolete">Epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="121"/>
         <source>Downloading</source>
-        <translation>Ladataan</translation>
+        <translation type="obsolete">Ladataan</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="156"/>
         <source>Paused</source>
-        <translation>Pysäytetty</translation>
+        <translation type="obsolete">Pysäytetty</translation>
     </message>
 </context>
 <context>
@@ -388,12 +373,12 @@
         <translation>Otsikko</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="71"/>
+        <location filename="../NewPlaylistDialog.qml" line="59"/>
         <source>Description (optional)</source>
         <translation>Kuvasu (valinnainen)</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="95"/>
+        <location filename="../NewPlaylistDialog.qml" line="71"/>
         <source>Private?</source>
         <translation>Yksityinen?</translation>
     </message>
@@ -516,33 +501,48 @@
         <translation>Ei soittolistoja</translation>
     </message>
 </context>
+<context>
+    <name>ProxyDialog</name>
+    <message>
+        <location filename="../ProxyDialog.qml" line="30"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="44"/>
+        <source>Host (e.g. 192.168.100.1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="51"/>
+        <source>Port (e.g. 8080)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchBar</name>
     <message>
-        <location filename="../SearchBar.qml" line="116"/>
-        <location filename="../SearchBar.qml" line="126"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Date</source>
         <translation>Pvm</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="117"/>
-        <location filename="../SearchBar.qml" line="119"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Relevance</source>
         <translation>Sopivuus</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="120"/>
-        <location filename="../SearchBar.qml" line="122"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Rating</source>
         <translation>Arvio</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="123"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Views</source>
         <translation>Katseluja</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="176"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Järjestä: </translation>
     </message>
@@ -550,223 +550,317 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
         <source>Mobile</source>
         <translation>Mobiili</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
-        <translation>Korkea laatu</translation>
+        <translation type="obsolete">Korkea laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
         <location filename="../SettingsDialog.qml" line="39"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automaattisesti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="42"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
         <translation>Manuaalisesti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="46"/>
-        <location filename="../SettingsDialog.qml" line="78"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
         <translation>On</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="49"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
         <translation>Pois</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Automatic</source>
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Landscape</source>
         <translation>Vaaka</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Portrait</source>
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="129"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
+        <source>Russian</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most viewed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Archive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Latest subscription videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My uploads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="501"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Light</source>
         <translation>Vaalea</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Dark</source>
         <translation>Tumma</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>English</source>
         <translation>Englanti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>German</source>
         <translation>Saksa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Finnish</source>
         <translation>Suomi</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Italian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Dutch</source>
         <translation>Alankomaiden</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Polish</source>
         <translation>Puolalainen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
-        <translation>Jonossa</translation>
+        <translation type="obsolete">Jonossa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
-        <translation>Pysäytetty</translation>
+        <translation type="obsolete">Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="85"/>
+        <location filename="../SettingsDialog.qml" line="102"/>
         <source>Your settings have been saved</source>
         <translation>Asetukset tallennettu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="90"/>
-        <location filename="../SettingsDialog.qml" line="120"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
         <source>Download Path</source>
         <translation>Latauspolku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="92"/>
+        <location filename="../SettingsDialog.qml" line="109"/>
         <source>Download Location</source>
         <translation>Lataussijainti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="111"/>
-        <location filename="../SettingsDialog.qml" line="320"/>
+        <location filename="../SettingsDialog.qml" line="117"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="141"/>
+        <location filename="../SettingsDialog.qml" line="391"/>
         <source>Playback Quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
-        <location filename="../SettingsDialog.qml" line="338"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="409"/>
         <source>Download Quality</source>
         <translation>Latauksen laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="117"/>
-        <location filename="../SettingsDialog.qml" line="356"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="427"/>
         <source>Start Downloads</source>
         <translation>Käynnistä lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="123"/>
-        <location filename="../SettingsDialog.qml" line="261"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="465"/>
         <source>Safe Search</source>
         <translation>Turvallinen Haku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="126"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
+        <location filename="../SettingsDialog.qml" line="483"/>
         <source>Screen Orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="132"/>
-        <location filename="../SettingsDialog.qml" line="285"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
+        <location filename="../SettingsDialog.qml" line="519"/>
         <source>Theme</source>
         <translation>Teema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="135"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
-        <location filename="../SettingsDialog.qml" line="466"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="345"/>
+        <location filename="../SettingsDialog.qml" line="537"/>
         <source>Language</source>
         <translation>Kieli</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="619"/>
+        <source>Widget Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="174"/>
+        <location filename="../SettingsDialog.qml" line="639"/>
+        <source>Widget Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="659"/>
+        <source>Widget Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="679"/>
+        <source>Widget Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="189"/>
         <source>Your saved searches have been cleared</source>
         <translation>Tallennetut hakusanat on tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="192"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="196"/>
+        <location filename="../SettingsDialog.qml" line="239"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="229"/>
+        <location filename="../SettingsDialog.qml" line="272"/>
+        <source>Network proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="280"/>
         <source>Playback quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="237"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Download quality</source>
         <translation>Latauksien laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="245"/>
+        <location filename="../SettingsDialog.qml" line="296"/>
         <source>Start downloads</source>
         <translation>Aloita lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="253"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Download location</source>
         <translation>Latauskansio</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="269"/>
+        <location filename="../SettingsDialog.qml" line="312"/>
+        <source>Safe search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Screen orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>Media player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="480"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="568"/>
+        <source>Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="576"/>
+        <source>Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="584"/>
+        <source>Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="592"/>
+        <source>Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="694"/>
         <source>Clear saved searches</source>
         <translation>Tyhjennä hakusanat</translation>
     </message>
@@ -878,7 +972,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="251"/>
+        <location filename="../UploadDialog.qml" line="215"/>
         <source>Category</source>
         <translation>Kategoria</translation>
     </message>
@@ -894,7 +988,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="259"/>
+        <location filename="../UploadDialog.qml" line="223"/>
         <source>None chosen</source>
         <translation>Ei valittuja</translation>
     </message>
@@ -904,17 +998,17 @@
         <translation>Otsikko</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="176"/>
         <source>Description (optional)</source>
         <translation>Kuvaus (valinnainen)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="212"/>
+        <location filename="../UploadDialog.qml" line="188"/>
         <source>Tags (seperated by commas)</source>
         <translation>Tagit (eroittele pilkulla)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="237"/>
+        <location filename="../UploadDialog.qml" line="201"/>
         <source>Private?</source>
         <translation>Yksityinen?</translation>
     </message>
@@ -1208,9 +1302,8 @@
 <context>
     <name>VideoPlaybackView</name>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="60"/>
         <source>Error: Unable to retrieve video</source>
-        <translation>Virhe: videon lataus epäonnistui</translation>
+        <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
     </message>
 </context>
 <context>
@@ -1308,49 +1401,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="39"/>
+        <location filename="../../../youtube.cpp" line="40"/>
         <source>Error obtaining access token</source>
         <translation>Virhe haettaessa varmennetta</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="49"/>
+        <location filename="../../../youtube.cpp" line="50"/>
         <source>Authentication failed</source>
         <translation>Varmennus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="52"/>
+        <location filename="../../../youtube.cpp" line="53"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Olet kirjautunut YouTubeen tilillä: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="116"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Error - Server repsonse is: </source>
         <translation>Virhe - Palvelin vastasi: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="166"/>
+        <location filename="../../../youtube.cpp" line="174"/>
         <source>Upload aborted</source>
         <translation>Lataus keskeytetty</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="181"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload failed</source>
         <translation>Lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="191"/>
         <source>Upload is completed</source>
         <translation>Lataus valmistui</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="382"/>
+        <location filename="../../../youtube.cpp" line="419"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1358,17 +1452,12 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="18"/>
         <source>Dark</source>
-        <translation>Tumma</translation>
+        <translation type="obsolete">Tumma</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="21"/>
-        <location filename="../main.qml" line="22"/>
-        <location filename="../main.qml" line="23"/>
-        <location filename="../main.qml" line="24"/>
         <source>Light</source>
-        <translation>Vaalea</translation>
+        <translation type="obsolete">Vaalea</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1396,9 +1485,13 @@
         <translation>Uusi soittolista luotu</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
-        <translation>Muunnetaan</translation>
+        <translation type="obsolete">Muunnetaan</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="204"/>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../main.qml" line="209"/>
@@ -1411,24 +1504,57 @@
         <translation> epäonnistui</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="230"/>
-        <location filename="../main.qml" line="270"/>
+        <location filename="../main.qml" line="224"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>Mobile</source>
+        <translation type="unfinished">Mobiili</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>360p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>480p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>720p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
+        <location filename="../main.qml" line="225"/>
         <source>Paused</source>
         <translation>Keskeytetty</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="225"/>
+        <source>Downloading</source>
+        <translation type="unfinished">Ladataan</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
+        <source>Failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="422"/>
         <source>Most Recent</source>
         <translation>Tuoreimmat</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="423"/>
         <source>Most Viewed</source>
         <translation>Katsotuimmat</translation>
     </message>
@@ -1445,57 +1571,52 @@
         <translation>Oma kanavani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="133"/>
+        <location filename="../scripts/mainscripts.js" line="134"/>
         <source>Archive</source>
         <translation>Arkisto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="172"/>
+        <location filename="../scripts/mainscripts.js" line="173"/>
         <source>My Playlists</source>
         <translation>Omat soittolistani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="182"/>
+        <location filename="../scripts/mainscripts.js" line="183"/>
         <source>My Subscriptions</source>
         <translation>Omat tilaukseni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="195"/>
+        <location filename="../scripts/mainscripts.js" line="196"/>
         <source>Video Info</source>
         <translation>Videon tiedot</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="204"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>Video Playback</source>
         <translation>Videon toisto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="214"/>
         <source>Downloads</source>
-        <translation>Lataukset</translation>
+        <translation type="obsolete">Lataukset</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="222"/>
         <source>date</source>
-        <translation>pvm</translation>
+        <translation type="obsolete">pvm</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="225"/>
         <source>views</source>
-        <translation>katselut</translation>
+        <translation type="obsolete">katselut</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="228"/>
         <source>relevance</source>
-        <translation>liittyvät</translation>
+        <translation type="obsolete">liittyvät</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="231"/>
         <source>rating</source>
-        <translation>arvio</translation>
+        <translation type="obsolete">arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="239"/>
+        <location filename="../scripts/mainscripts.js" line="218"/>
         <source>Search </source>
         <translation>Haku</translation>
     </message>
@@ -1503,39 +1624,32 @@
 <context>
     <name>settings</name>
     <message>
-        <location filename="../scripts/settings.js" line="126"/>
-        <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
-        <translation>Korkea laatu</translation>
+        <translation type="obsolete">Korkea laatu</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
-        <translation>Pysäytetty</translation>
+        <translation type="obsolete">Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
-        <translation>Automaattinen</translation>
+        <translation type="obsolete">Automaattinen</translation>
     </message>
     <message>
         <source>Media Player</source>
         <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
-        <translation>Pvm</translation>
+        <translation type="obsolete">Pvm</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
-        <translation>Tumma</translation>
+        <translation type="obsolete">Tumma</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
-        <translation>Englanti</translation>
+        <translation type="obsolete">Englanti</translation>
     </message>
 </context>
 <context>
