@@ -66,7 +66,7 @@
     <message>
         <location filename="../AddCommentDialog.qml" line="15"/>
         <source>Share Via </source>
-        <translation>Condividi Tramite</translation>
+        <translation>Condividi Tramite </translation>
     </message>
     <message>
         <location filename="../AddCommentDialog.qml" line="60"/>
@@ -408,7 +408,7 @@
     <message>
         <location filename="../OAuthDialog.qml" line="8"/>
         <source>Authorisation For </source>
-        <translation>Autorizzazione Per</translation>
+        <translation>Autorizzazione Per </translation>
     </message>
     <message>
         <location filename="../OAuthDialog.qml" line="27"/>
@@ -490,17 +490,17 @@
     <message>
         <location filename="../ProxyDialog.qml" line="30"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="44"/>
         <source>Host (e.g. 192.168.100.1)</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="51"/>
         <source>Port (e.g. 8080)</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -581,37 +581,37 @@
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
         <source>Russian</source>
-        <translation type="unfinished"></translation>
+        <translation>Russo</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
         <source>Most recent</source>
-        <translation type="unfinished"></translation>
+        <translation>I più recenti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
         <source>Most viewed</source>
-        <translation type="unfinished"></translation>
+        <translation>I più recenti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
         <source>Archive</source>
-        <translation type="unfinished">Archivio</translation>
+        <translation>Archivio</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
         <source>Latest subscription videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Novità da iscrizioni</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
         <source>My uploads</source>
-        <translation type="unfinished"></translation>
+        <translation>I miei video</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
         <source>My favourites</source>
-        <translation type="unfinished"></translation>
+        <translation>I miei preferiti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="159"/>
@@ -628,7 +628,7 @@
         <location filename="../SettingsDialog.qml" line="37"/>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>High quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Alta qualità</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="42"/>
@@ -648,12 +648,12 @@
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
         <source>Finnish</source>
-        <translation></translation>
+        <translation>Finlandese</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
         <source>Italian</source>
-        <translation></translation>
+        <translation>Italiano</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
@@ -693,7 +693,7 @@
         <location filename="../SettingsDialog.qml" line="117"/>
         <location filename="../SettingsDialog.qml" line="168"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="141"/>
@@ -743,25 +743,25 @@
         <location filename="../SettingsDialog.qml" line="171"/>
         <location filename="../SettingsDialog.qml" line="619"/>
         <source>Widget Feed One</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Widget Uno</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="174"/>
         <location filename="../SettingsDialog.qml" line="639"/>
         <source>Widget Feed Two</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Widget Due</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="177"/>
         <location filename="../SettingsDialog.qml" line="659"/>
         <source>Widget Feed Three</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Widget Tre</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="180"/>
         <location filename="../SettingsDialog.qml" line="679"/>
         <source>Widget Feed Four</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Widget Quattro</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="189"/>
@@ -781,7 +781,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="272"/>
         <source>Network proxy</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="280"/>
@@ -806,7 +806,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="312"/>
         <source>Safe search</source>
-        <translation type="unfinished"></translation>
+        <translation>Ricerca sicura</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="320"/>
@@ -821,27 +821,27 @@
     <message>
         <location filename="../SettingsDialog.qml" line="364"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessuna</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="568"/>
         <source>Feed One</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Uno</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="576"/>
         <source>Feed Two</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Due</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="584"/>
         <source>Feed Three</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Tre</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="592"/>
         <source>Feed Four</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Quattro</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="694"/>
@@ -1443,7 +1443,7 @@
     <message>
         <location filename="../main.qml" line="204"/>
         <source>Audio</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="209"/>
@@ -1458,27 +1458,27 @@
     <message>
         <location filename="../main.qml" line="224"/>
         <source>High quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Altà qualità</translation>
     </message>
     <message>
         <location filename="../main.qml" line="224"/>
         <source>Mobile</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="224"/>
         <source>360p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="224"/>
         <source>480p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="224"/>
         <source>720p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="225"/>
@@ -1493,12 +1493,12 @@
     <message>
         <location filename="../main.qml" line="225"/>
         <source>Downloading</source>
-        <translation type="unfinished">In Download</translation>
+        <translation>In Download</translation>
     </message>
     <message>
         <location filename="../main.qml" line="225"/>
         <source>Failed</source>
-        <translation type="unfinished">Fallito</translation>
+        <translation>Fallito</translation>
     </message>
     <message>
         <location filename="../main.qml" line="422"/>
