@@ -5,8 +5,8 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.6.3</source>
-        <translation></translation>
+        <source>cuteTube-QML - 0.6.5</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -38,12 +38,12 @@
         <translation>Gebruikersnaam</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="107"/>
+        <location filename="../AccountDetailsDialog.qml" line="95"/>
         <source>Password</source>
         <translation>Wachtwoord</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="132"/>
+        <location filename="../AccountDetailsDialog.qml" line="108"/>
         <source>Default?</source>
         <translation>Standaard?</translation>
     </message>
@@ -74,12 +74,12 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="87"/>
+        <location filename="../AddCommentDialog.qml" line="74"/>
         <source>Description</source>
         <translation>Beschrijving</translation>
     </message>
     <message>
-        <location filename="../AddCommentDialog.qml" line="124"/>
+        <location filename="../AddCommentDialog.qml" line="111"/>
         <source>Message</source>
         <translation>Bericht</translation>
     </message>
@@ -167,52 +167,46 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
-        <translation>Engels</translation>
+        <translation type="obsolete">Engels</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
-        <translation>Duits</translation>
+        <translation type="obsolete">Duits</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
         <source>Italian</source>
-        <translation>Italiaans</translation>
+        <translation type="obsolete">Italiaans</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
-        <translation>Fins</translation>
+        <translation type="obsolete">Fins</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="50"/>
         <source>Dutch</source>
-        <translation>Nederlands</translation>
+        <translation type="obsolete">Nederlands</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="51"/>
         <source>Polish</source>
-        <translation>Pools</translation>
+        <translation type="obsolete">Pools</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="177"/>
+        <location filename="../../../controller.cpp" line="181"/>
         <source>Video deleted from device</source>
         <translation>Video verwijderd van telefoon</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="180"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Unable to delete video</source>
         <translation>Kan video niet verwijderen</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="184"/>
+        <location filename="../../../controller.cpp" line="188"/>
         <source>Video not found</source>
         <translation>Video niet gevonden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="239"/>
+        <location filename="../../../controller.cpp" line="243"/>
         <source>Copied to clipboard</source>
         <translation>Gekopieerd naar het klembord</translation>
     </message>
@@ -220,44 +214,35 @@
 <context>
     <name>DownloadListDelegate</name>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Paused</source>
-        <translation>onderbroken</translation>
+        <translation type="obsolete">onderbroken</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Queued</source>
-        <translation>Wachtrij</translation>
+        <translation type="obsolete">Wachtrij</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Failed</source>
-        <translation>Mislukt</translation>
+        <translation type="obsolete">Mislukt</translation>
     </message>
     <message>
-        <location filename="../DownloadListDelegate.qml" line="66"/>
         <source>Downloading</source>
-        <translation>Downloaden</translation>
+        <translation type="obsolete">Downloaden</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="37"/>
-        <location filename="../../../downloadmanager.cpp" line="66"/>
-        <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
-        <translation>Mislukt</translation>
+        <translation type="obsolete">Mislukt</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="121"/>
         <source>Downloading</source>
-        <translation>Downloaden</translation>
+        <translation type="obsolete">Downloaden</translation>
     </message>
     <message>
-        <location filename="../../../downloadmanager.cpp" line="156"/>
         <source>Paused</source>
-        <translation>Onderbroken</translation>
+        <translation type="obsolete">Onderbroken</translation>
     </message>
 </context>
 <context>
@@ -380,12 +365,12 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="71"/>
+        <location filename="../NewPlaylistDialog.qml" line="59"/>
         <source>Description (optional)</source>
         <translation>Beschrijving (optioneel)</translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="95"/>
+        <location filename="../NewPlaylistDialog.qml" line="71"/>
         <source>Private?</source>
         <translation>Prive?</translation>
     </message>
@@ -508,33 +493,48 @@
         <translation>Geen afspeellijst gevonden</translation>
     </message>
 </context>
+<context>
+    <name>ProxyDialog</name>
+    <message>
+        <location filename="../ProxyDialog.qml" line="30"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="44"/>
+        <source>Host (e.g. 192.168.100.1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ProxyDialog.qml" line="51"/>
+        <source>Port (e.g. 8080)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchBar</name>
     <message>
-        <location filename="../SearchBar.qml" line="116"/>
-        <location filename="../SearchBar.qml" line="126"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="117"/>
-        <location filename="../SearchBar.qml" line="119"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Relevance</source>
         <translation>Relevantie</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="120"/>
-        <location filename="../SearchBar.qml" line="122"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Rating</source>
         <translation>Beoordeling</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="123"/>
+        <location filename="../SearchBar.qml" line="15"/>
         <source>Views</source>
         <translation>Bekenen</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="176"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Sorteren op:</translation>
     </message>
@@ -542,223 +542,317 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="189"/>
         <source>Your saved searches have been cleared</source>
         <translation>Uw opgeslagen zoekopdrachten zijn verwijderd</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="192"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Database fout. Kan zoekopdrachten niet verwijderen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="196"/>
+        <location filename="../SettingsDialog.qml" line="239"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="229"/>
+        <location filename="../SettingsDialog.qml" line="280"/>
         <source>Playback quality</source>
         <translation>Afspeel kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="237"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Download quality</source>
         <translation>Download kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="245"/>
+        <location filename="../SettingsDialog.qml" line="296"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="253"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Download location</source>
         <translation>Download locatie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="269"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Screen orientation</source>
         <translation>Scherm orientatie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="135"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
-        <location filename="../SettingsDialog.qml" line="466"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="345"/>
+        <location filename="../SettingsDialog.qml" line="537"/>
         <source>Language</source>
         <translation>Taal</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="111"/>
-        <location filename="../SettingsDialog.qml" line="320"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="43"/>
+        <source>Russian</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Most viewed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Archive</source>
+        <translation type="unfinished">Archief</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Latest subscription videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My uploads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <source>My favourites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="117"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <source>Network Proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="141"/>
+        <location filename="../SettingsDialog.qml" line="391"/>
         <source>Playback Quality</source>
         <translation>Afspeel Kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
-        <location filename="../SettingsDialog.qml" line="338"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="409"/>
         <source>Download Quality</source>
         <translation>Download Kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="117"/>
-        <location filename="../SettingsDialog.qml" line="356"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="427"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="126"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
+        <location filename="../SettingsDialog.qml" line="483"/>
         <source>Screen Orientation</source>
         <translation>Scherm Orientatie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="129"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="501"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
         <source>Mobile</source>
         <translation>Mobiele kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="17"/>
-        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
-        <translation>Hoge Kwaliteit</translation>
+        <translation type="obsolete">Hoge Kwaliteit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
         <location filename="../SettingsDialog.qml" line="39"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="42"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
         <translation>Handmatig</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="46"/>
-        <location filename="../SettingsDialog.qml" line="78"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
         <translation>Aan</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="49"/>
+        <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
         <translation>Uit</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Landscape</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Portrait</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Light</source>
         <translation>Licht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="23"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Dark</source>
         <translation>Donker</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>English</source>
         <translation>Engels</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>German</source>
         <translation>Duits</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Finnish</source>
         <translation>Fins</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Italian</source>
         <translation>Italiaans</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Dutch</source>
         <translation>Nederlands</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="24"/>
+        <location filename="../SettingsDialog.qml" line="43"/>
         <source>Polish</source>
         <translation>Pools</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
-        <translation>Wachtrij</translation>
+        <translation type="obsolete">Wachtrij</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
-        <translation>Pause</translation>
+        <translation type="obsolete">Pause</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="85"/>
+        <location filename="../SettingsDialog.qml" line="102"/>
         <source>Your settings have been saved</source>
         <translation>Uw instellingen zijn opgeslagen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="90"/>
-        <location filename="../SettingsDialog.qml" line="120"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
         <source>Download Path</source>
         <translation>Download Pad</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="92"/>
+        <location filename="../SettingsDialog.qml" line="109"/>
         <source>Download Location</source>
         <translation>Download Locatie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="123"/>
-        <location filename="../SettingsDialog.qml" line="261"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="465"/>
         <source>Safe Search</source>
         <translation>Veilig Zoeken</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="132"/>
-        <location filename="../SettingsDialog.qml" line="285"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
+        <location filename="../SettingsDialog.qml" line="519"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="480"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="619"/>
+        <source>Widget Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="174"/>
+        <location filename="../SettingsDialog.qml" line="639"/>
+        <source>Widget Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="659"/>
+        <source>Widget Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="679"/>
+        <source>Widget Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="272"/>
+        <source>Network proxy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="312"/>
+        <source>Safe search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="364"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="568"/>
+        <source>Feed One</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="576"/>
+        <source>Feed Two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="584"/>
+        <source>Feed Three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="592"/>
+        <source>Feed Four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="694"/>
         <source>Clear saved searches</source>
         <translation>Verwijder opgeslagen zoekopdrachten</translation>
     </message>
@@ -870,7 +964,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="251"/>
+        <location filename="../UploadDialog.qml" line="215"/>
         <source>Category</source>
         <translation>Categorie</translation>
     </message>
@@ -886,7 +980,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="259"/>
+        <location filename="../UploadDialog.qml" line="223"/>
         <source>None chosen</source>
         <translation>Geen gekozen</translation>
     </message>
@@ -896,17 +990,17 @@
         <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="176"/>
         <source>Description (optional)</source>
         <translation>Beschrijving (optioneel)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="212"/>
+        <location filename="../UploadDialog.qml" line="188"/>
         <source>Tags (seperated by commas)</source>
         <translation>Labels (gescheiden door komma&apos;s)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="237"/>
+        <location filename="../UploadDialog.qml" line="201"/>
         <source>Private?</source>
         <translation>Privé?</translation>
     </message>
@@ -1200,9 +1294,8 @@
 <context>
     <name>VideoPlaybackView</name>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="60"/>
         <source>Error: Unable to retrieve video</source>
-        <translation>Fout: Kan geen video ophalen</translation>
+        <translation type="obsolete">Fout: Kan geen video ophalen</translation>
     </message>
 </context>
 <context>
@@ -1216,49 +1309,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="39"/>
+        <location filename="../../../youtube.cpp" line="40"/>
         <source>Error obtaining access token</source>
         <translation>Fout bij het verkijgen van een toegangs certificaat</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="49"/>
+        <location filename="../../../youtube.cpp" line="50"/>
         <source>Authentication failed</source>
         <translation>Authenticatie is mislukt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="52"/>
+        <location filename="../../../youtube.cpp" line="53"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>U bent aangemeld bij YouTube als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="116"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Error - Server repsonse is: </source>
         <translation>Error - Server antwoord is:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="166"/>
+        <location filename="../../../youtube.cpp" line="174"/>
         <source>Upload aborted</source>
         <translation>Upload gestopt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="181"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload onderbroken. Probeert te hervatten ...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload failed</source>
         <translation>Upload mislukt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="191"/>
         <source>Upload is completed</source>
         <translation>Upload is voltooid</translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="382"/>
+        <location filename="../../../youtube.cpp" line="419"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fout: Kan geen video ophalen</translation>
     </message>
@@ -1266,17 +1360,12 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="18"/>
         <source>Dark</source>
-        <translation>Donker</translation>
+        <translation type="obsolete">Donker</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="21"/>
-        <location filename="../main.qml" line="22"/>
-        <location filename="../main.qml" line="23"/>
-        <location filename="../main.qml" line="24"/>
         <source>Light</source>
-        <translation>Licht</translation>
+        <translation type="obsolete">Licht</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1304,9 +1393,13 @@
         <translation>Nieuwe afspeellijst gemaakt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
-        <translation>Omzetten</translation>
+        <translation type="obsolete">Omzetten</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="204"/>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../main.qml" line="209"/>
@@ -1319,24 +1412,57 @@
         <translation>&apos; mislukt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="230"/>
-        <location filename="../main.qml" line="270"/>
+        <location filename="../main.qml" line="224"/>
+        <source>High quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>Mobile</source>
+        <translation type="unfinished">Mobiele kwaliteit</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>360p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>480p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="224"/>
+        <source>720p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
         <source>Queued</source>
         <translation>Wachtrij</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
+        <location filename="../main.qml" line="225"/>
         <source>Paused</source>
         <translation>Gepauzeerd</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="225"/>
+        <source>Downloading</source>
+        <translation type="unfinished">Downloaden</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="225"/>
+        <source>Failed</source>
+        <translation type="unfinished">Mislukt</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="422"/>
         <source>Most Recent</source>
         <translation>Meest Recent</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="423"/>
         <source>Most Viewed</source>
         <translation>Meest Bekeken</translation>
     </message>
@@ -1349,57 +1475,48 @@
         <translation>Mijn Kanaal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="133"/>
+        <location filename="../scripts/mainscripts.js" line="134"/>
         <source>Archive</source>
         <translation>Archief</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="172"/>
+        <location filename="../scripts/mainscripts.js" line="173"/>
         <source>My Playlists</source>
         <translation>Mijn Afspeellijst</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="182"/>
+        <location filename="../scripts/mainscripts.js" line="183"/>
         <source>My Subscriptions</source>
         <translation>Mijn Abonnementen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="195"/>
+        <location filename="../scripts/mainscripts.js" line="196"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="204"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>Video Playback</source>
         <translation>Video Afspelen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="214"/>
-        <source>Downloads</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="222"/>
         <source>date</source>
-        <translation>datum</translation>
+        <translation type="obsolete">datum</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="225"/>
         <source>views</source>
-        <translation>bekeken</translation>
+        <translation type="obsolete">bekeken</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="228"/>
         <source>relevance</source>
-        <translation>relevantie</translation>
+        <translation type="obsolete">relevantie</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="231"/>
         <source>rating</source>
-        <translation>beoordelingen</translation>
+        <translation type="obsolete">beoordelingen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="239"/>
+        <location filename="../scripts/mainscripts.js" line="218"/>
         <source>Search </source>
         <translation>Zoeken </translation>
     </message>
@@ -1407,35 +1524,28 @@
 <context>
     <name>settings</name>
     <message>
-        <location filename="../scripts/settings.js" line="126"/>
-        <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
-        <translation>Hoge Kwaliteit</translation>
+        <translation type="obsolete">Hoge Kwaliteit</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
-        <translation>Gepauzeerd</translation>
+        <translation type="obsolete">Gepauzeerd</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
-        <translation>Automatisch</translation>
+        <translation type="obsolete">Automatisch</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
-        <translation>Datum</translation>
+        <translation type="obsolete">Datum</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
-        <translation>Donker</translation>
+        <translation type="obsolete">Donker</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
-        <translation>Engels</translation>
+        <translation type="obsolete">Engels</translation>
     </message>
 </context>
 </TS>
