@@ -66,26 +66,36 @@ function getSubscriptions() {
     doc.onreadystatechange = function() {
         if (doc.readyState == XMLHttpRequest.DONE) {
             var xml = doc.responseText;
-            subscriptionsModel.xml = xml;
+            if (subscriptionsModel.count == 0) {
+                subscriptionsModel.setXml(xml);
+            }
+            else {
+                subscriptionsModel.appendXml(xml);
+            }
         }
     }
-    doc.open("GET", "http://gdata.youtube.com/feeds/api/users/default/subscriptions?v=2");
+    doc.open("GET", _SUBSCRIPTIONS_FEED + "&start-index=" + (subscriptionsModel.count + 1).toString());
     doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
     doc.send();
 }
 
 function getPlaylists() {
-    /* Retrieve the user's subscriptions and
+    /* Retrieve the user's playlists and
       populate the model */
 
     var doc = new XMLHttpRequest();
     doc.onreadystatechange = function() {
         if (doc.readyState == XMLHttpRequest.DONE) {
             var xml = doc.responseText;
-            playlistModel.xml = xml;
+            if (playlistModel.count == 0) {
+                playlistModel.setXml(xml);
+            }
+            else {
+                playlistModel.appendXml(xml);
+            }
         }
     }
-    doc.open("GET", "http://gdata.youtube.com/feeds/api/users/default/playlists?v=2");
+    doc.open("GET", _PLAYLISTS_FEED + "&start-index=" + (playlistModel.count + 1).toString());
     doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
     doc.send();
 }
@@ -198,7 +208,7 @@ function loadVideoInfo(video) {
 }
 
 function loadPlaybackView(videoList) {
-    Controller.setOrientation("Landscape");
+    Controller.setOrientation("landscape");
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     toggleControls(false);
