@@ -15,6 +15,10 @@ function initialize() {
                     tx.executeSql('CREATE TABLE IF NOT EXISTS savedDownloads (filePath TEXT UNIQUE, playerUrl TEXT, title TEXT, thumbnail TEXT, convert INTEGER)');
                     tx.executeSql('CREATE TABLE IF NOT EXISTS archive (filePath TEXT UNIQUE, title TEXT, thumbnail TEXT, quality TEXT, isNew INTEGER)');
                     tx.executeSql('CREATE TABLE IF NOT EXISTS oauth(service TEXT UNIQUE, token TEXT, secret TEXT)');
+                    if (getSetting("resetSettings") == "unknown") {
+                        tx.executeSql('DROP TABLE IF EXISTS settings');
+                        tx.executeSql('CREATE TABLE settings(setting TEXT UNIQUE, value TEXT)');
+                    }
                     setDefaultSettings();
                 });
 }
@@ -123,16 +127,22 @@ function getAllAccounts() {
 function setDefaultSettings() {
     /* Set defaults if no settings exist */
 
-    var settings = [ [ "playbackQuality", qsTr("High Quality") ],
-                    [ "downloadQuality", qsTr("High Quality") ],
-                    [ "downloadStatus", qsTr("Paused") ],
+    var settings = [ [ "playbackQuality", "hq" ],
+                    [ "downloadQuality", "hq" ],
+                    [ "downloadStatus", "paused" ],
                     [ "downloadPath", "/home/user/MyDocs/.cutetube/" ],
                     [ "safeSearch", "none" ],
-                    [ "screenOrientation", qsTr("Automatic") ],
+                    [ "screenOrientation", "automatic" ],
                     [ "mediaPlayer", "Media Player" ],
-                    [ "searchOrder", qsTr("Date") ],
-                    [ "theme", qsTr("Dark") ],
-                    [ "language", qsTr("English") ] ];
+                    [ "searchOrder", "published" ],
+                    [ "theme", "dark" ],
+                    [ "language", "en" ],
+                    [ "proxy", ":"],
+                    [ "widgetFeedOne", "_MOST_RECENT_FEED" ],
+                    [ "widgetFeedTwo", "_MOST_VIEWED_FEED" ],
+                    [ "widgetFeedThree", "archive" ],
+                    [ "widgetFeedFour", "_NEW_SUB_VIDEOS_FEED" ],
+                    [ "resetSettings", "no"] ];
 
     for (var i = 0; i < settings.length; i++) {
         var setting = settings[i][0];
