@@ -25,7 +25,7 @@ void YouTube::setPlaybackQuality(const QString &quality) {
 }
 
 void YouTube::login(const QString &username, const QString &password) {
-    setCurrentUser(username, password);
+    setCurrentUser(username);
     QNetworkRequest request(QUrl("https://www.google.com/accounts/ClientLogin"));
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QByteArray loginData("Email=" + username.toAscii() + "&Passwd=" + password.toAscii() + "&service=youtube&source=cuteTube");
@@ -36,28 +36,33 @@ void YouTube::login(const QString &username, const QString &password) {
 void YouTube::checkLogin() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
-        setCurrentUser("", "");
+        setCurrentUser("");
         emit alert(tr("Error obtaining access token"));
         return;
     }
 
     QByteArray response = reply->readAll();
+//    qDebug() << response;
     QList<QByteArray> sp = response.split('=');
-    setAccessToken(sp.last().trimmed());
+    QByteArray token = sp.last().trimmed();
 
-    if (getAccessToken() == "BadAuthentication") {
-        setCurrentUser("", "");
+    if (sp.first() == "Error") {
+        setCurrentUser("");
+        emit alert(sp.first() + ": " + sp.at(1).split('\n').first());
+    }
+    else if ((token.isEmpty()) || (token == "BadAuthentication")) {
+        setCurrentUser("");
         emit alert(tr("Authentication failed"));
     }
     else {
+        setAccessToken(token);
         emit alert(tr("You are signed in to YouTube as '") + getCurrentUser() + "'");
     }
     reply->deleteLater();
 }
 
-void YouTube::setCurrentUser(const QString &user, const QString &pass) {
+void YouTube::setCurrentUser(const QString &user) {
     currentUser = user;
-    currentUserPass = pass;
     emit currentUserChanged();
 }
 
