@@ -46,7 +46,7 @@ public slots:
 
 private slots:
     void checkLogin();
-    void setCurrentUser(const QString &user, const QString &pass);
+    void setCurrentUser(const QString &user);
     void setAccessToken(const QByteArray &token);
     void setUploadUrl();
     void performVideoUpload();
@@ -67,7 +67,6 @@ private:
     QByteArray developerKey;
     QString accessToken;
     QString currentUser;
-    QString currentUserPass;
     int playbackFormat;
     QHash<QString, int> pbMap;
     QString message;
